### **Interface Directory**

1. **`mlflow_interface.py`**
    - This file defines the `FederatedModel` class, which encapsulates the local learner, the aggregation strategy, and their respective names. It facilitates the integration of these components into the MLflow tracking system. It also includes the `submit_fl_model` function for logging the model to MLflow.

2. **`aggregator.py`**
    - This file defines the `AggFactoryProtocol` and `AggProtocol` protocols. The `AggFactoryProtocol` is a protocol for the function creating the aggregator instance, while the `AggProtocol` defines the methods and attributes that an aggregator must implement.

3. **`local_learner.py`**
    - This file defines the `LLFactoryProtocol` and `LLProtocol` protocols. The `LLFactoryProtocol` is a protocol for the function creating the local learner instance, while the `LLProtocol` defines the methods and attributes that a local learner must implement. This file provides the structure for implementing custom local learners.

4. **`default_create_functions.py`**
    - This file provides default implementations for creating local learners and aggregators. The `default_create_local_learner` and `default_create_aggregator` functions.

5. **`cli.py`**
    - This file contains the `create_structure` function, which sets up the project structure for uploading models to MLflow. It creates necessary directories and files, including `utils.py`, `example.py`, and `README.md`.

6. **`templates.py`**
    - This file contains template functions for generating the content of `utils.py`, `example.py`, and `README.md`. It includes the `get_utils_template`, `get_main_template`, and `get_readme_template` functions.

7. **`readme_template.txt`**
    - This file contains the template for the `README.md` file that is generated by the `create_structure` function. It provides a detailed guide on how to use the package functionalities.

8. **`src/utils.py`**
    - This file contains utility functions for managing and converting Flower objects. It includes methods for serializing and deserializing model parameters and other helper functions.